"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const MiniCssExtractPlugin = require("mini-css-extract-plugin");
const autoprefixer = require("autoprefixer");
const importOnce = require("../../node-sass-import-once");
// TODO: run in a separate process via thread-loader
//   https://webpack.js.org/guides/build-performance/#sass
exports.stylesConfigLayer = (projectConfig) => {
    return {
        module: {
            rules: [
                {
                    test: /\.s[ac]ss$/i,
                    use: [
                        MiniCssExtractPlugin.loader,
                        "css-loader",
                        {
                            loader: "postcss-loader",
                            options: {
                                plugins: [
                                    autoprefixer(projectConfig.env.browserlist),
                                ],
                            },
                        },
                        {
                            loader: "sass-loader",
                            options: {
                                sassOptions: {
                                    importer: importOnce(projectConfig.paths.projectNodeModules || ""),
                                    importOnce: {
                                        index: true,
                                        css: false,
                                        bower: false,
                                    },
                                }
                            },
                        },
                    ],
                },
                {
                    test: /\.css$/i,
                    use: [
                        MiniCssExtractPlugin.loader,
                        "css-loader",
                        {
                            loader: "postcss-loader",
                            options: {
                                plugins: [
                                    autoprefixer(projectConfig.env.browserlist),
                                ],
                            },
                        },
                    ]
                },
            ],
        },
        plugins: [
            new MiniCssExtractPlugin({
                filename: projectConfig.env.enableCacheBusting ? "[name].[contenthash].css" : "[name].css",
                chunkFilename: projectConfig.env.enableCacheBusting ? "[id].[contenthash].css" : "[id].css",
            }),
        ],
    };
};
